@@ -19,8 +19,8 @@
  *
  */
 
-#include "logging.h"
 #include "extractHereDndPlugin.h"
+#include "ark_debug.h"
 #include "batchextract.h"
 #include "kerfuffle/archive_kerfuffle.h"
 
@@ -31,8 +31,6 @@
 #include <kfileitemlistproperties.h>
 #include <KLocalizedString>
 
-Q_LOGGING_CATEGORY(ARK, "ark.extracthere", QtWarningMsg)
-
 K_PLUGIN_FACTORY_WITH_JSON(ExtractHereDndPluginFactory, "ark_dndextract.json",
                            registerPlugin<ExtractHereDndPlugin>();)
 
@@ -71,7 +69,7 @@ QList<QAction *> ExtractHereDndPlugin::setup(const KFileItemListProperties& popu
 
     qCDebug(ARK) << "Plugin executed";
 
-    QAction *action = new QAction(QIcon::fromTheme(QLatin1String("archive-extract")),
+    QAction *action = new QAction(QIcon::fromTheme(QStringLiteral("archive-extract")),
                                   extractHereMessage, NULL);
     connect(action, &QAction::triggered, this, &ExtractHereDndPlugin::slotTriggered);
 
