@@ -22,10 +22,10 @@
 #ifndef EXTRACTHEREDNDPLUGIN_H
 #define EXTRACTHEREDNDPLUGIN_H
 
-#include <kurl.h>
-#include <konq_dndpopupmenuplugin.h>
+#include <qurl.h>
+#include <KIO/DndPopupMenuPlugin>
 
-class ExtractHereDndPlugin : public KonqDndPopupMenuPlugin
+class ExtractHereDndPlugin : public KIO::DndPopupMenuPlugin
 {
     Q_OBJECT
 
@@ -35,12 +35,12 @@ private slots:
 public:
     ExtractHereDndPlugin(QObject* parent, const QVariantList&);
 
-    virtual void setup(const KFileItemListProperties& popupMenuInfo,
-                       KUrl destination,
-                       QList<QAction*>& userActions);
+    virtual QList<QAction *> setup(const KFileItemListProperties& popupMenuInfo,
+                                   const QUrl& destination);
+
 private:
-    KUrl m_dest;
-    QList<KUrl> m_urls;
+    QUrl m_dest;
+    QList<QUrl> m_urls;
 };
 
 #endif /* EXTRACTHEREDNDPLUGIN_H */
