@@ -23,8 +23,8 @@
 #define MAINWINDOW_H
 
 #include <KParts/MainWindow>
+#include <KParts/OpenUrlArguments>
 #include <KParts/ReadWritePart>
-#include <KUrl>
 
 class KRecentFilesAction;
 
@@ -36,12 +36,12 @@ public:
     ~MainWindow();
     bool loadPart();
 
-    void dragEnterEvent(class QDragEnterEvent * event);
-    void dropEvent(class QDropEvent * event);
-    void dragMoveEvent(class QDragMoveEvent * event);
+    void dragEnterEvent(class QDragEnterEvent * event) Q_DECL_OVERRIDE;
+    void dropEvent(class QDropEvent * event) Q_DECL_OVERRIDE;
+    void dragMoveEvent(class QDragMoveEvent * event) Q_DECL_OVERRIDE;
 
 public slots:
-    void openUrl(const KUrl& url);
+    void openUrl(const QUrl &url);
     void setShowExtractDialog(bool);
 
 private slots:
@@ -49,6 +49,8 @@ private slots:
     void newArchive();
     void openArchive();
     void quit();
+    void showSettings();
+    void writeSettings();
 
     void editKeyBindings();
     void editToolbars();
