@@ -52,6 +52,11 @@ public:
      */
     QString filename() const;
 
+    /**
+     * Returns the comment of the archive.
+     */
+    QString comment() const;
+
     /**
      * Returns whether the file can only be read.
      *
@@ -86,14 +91,16 @@ public:
      * @note If returning false, make sure to emit the error() signal beforewards to notify
      * the user of the error condition.
      */
-    virtual bool copyFiles(const QList<QVariant> & files, const QString & destinationDirectory, ExtractionOptions options) = 0;
-
+    virtual bool copyFiles(const QList<QVariant> &files, const QString &destinationDirectory, const ExtractionOptions &options) = 0;
     bool waitForFinishedSignal();
 
     virtual bool doKill();
     virtual bool doSuspend();
     virtual bool doResume();
 
+    virtual bool isCliBased() const;
+    virtual bool findExecutables(bool isReadWrite);
+
 signals:
     void cancelled();
     void error(const QString &message, const QString &details = QString());
@@ -113,14 +120,17 @@ protected:
      * the operation.
      */
     void setWaitForFinishedSignal(bool value);
-
     bool isHeaderEncryptionEnabled() const;
+    void setCorrupt(bool isCorrupt);
+    bool isCorrupt() const;
+    QString m_comment;
 
 private:
     QString m_filename;
     QString m_password;
     bool m_waitForFinishedSignal;
     bool m_isHeaderEncryptionEnabled;
+    bool m_isCorrupt;
 };
 
 class KERFUFFLE_EXPORT ReadWriteArchiveInterface: public ReadOnlyArchiveInterface
