@@ -138,7 +138,7 @@ void CreateDialog::accept()
 void CreateDialog::restoreWindowSize()
 {
     // Restore window size from config file, needs a windowHandle so must be called after show()
-    KConfigGroup group(KSharedConfig::openConfig(), "AddDialog");
+    KConfigGroup group(KSharedConfig::openConfig(), "CreateDialog");
     //KWindowConfig::restoreWindowSize(windowHandle(), group);
     //KWindowConfig::restoreWindowSize is broken atm., so we need this hack:
     const QRect desk = windowHandle()->screen()->geometry();
@@ -211,13 +211,15 @@ void CreateDialog::updateDisplayedOptions(const QString &filter)
         if (m_ui->groupEncryptionOptions->isEnabled()) {
             m_ui->encryptHeaderCheckBox->setToolTip(i18n("Protection of the list of files is not possible with the %1 format.",
                                                          QMimeDatabase().mimeTypeForName(filter).comment()));
+        } else {
+             m_ui->encryptHeaderCheckBox->setToolTip(QString());
         }
     }
 }
 
 void CreateDialog::loadConfiguration()
 {
-    m_config = KConfigGroup(KSharedConfig::openConfig()->group("AddDialog"));
+    m_config = KConfigGroup(KSharedConfig::openConfig()->group("CreateDialog"));
 
     const QString defaultMimeType = QStringLiteral("application/x-compressed-tar");
     const QString lastMimeType = m_config.readEntry("LastMimeType", defaultMimeType);
