@@ -25,9 +25,10 @@
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include "app/logging.h"
 #include "jobs.h"
+#include "ark_debug.h"
 
+#include <QFileInfo>
 #include <QThread>
 
 #include <KLocalizedString>
@@ -44,7 +45,7 @@ public:
         : QThread(parent)
         , q(job)
     {
-        connect(q, SIGNAL(result(KJob*)), SLOT(quit()));
+        connect(q, &KJob::result, this, &QThread::quit);
     }
 
     virtual void run() Q_DECL_OVERRIDE;
@@ -115,19 +116,19 @@ void Job::emitResult()
 
 void Job::connectToArchiveInterfaceSignals()
 {
-    connect(archiveInterface(), SIGNAL(cancelled()), SLOT(onCancelled()));
-    connect(archiveInterface(), SIGNAL(error(QString,QString)), SLOT(onError(QString,QString)));
-    connect(archiveInterface(), SIGNAL(entry(ArchiveEntry)), SLOT(onEntry(ArchiveEntry)));
-    connect(archiveInterface(), SIGNAL(entryRemoved(QString)), SLOT(onEntryRemoved(QString)));
-    connect(archiveInterface(), SIGNAL(progress(double)), SLOT(onProgress(double)));
-    connect(archiveInterface(), SIGNAL(info(QString)), SLOT(onInfo(QString)));
-    connect(archiveInterface(), SIGNAL(finished(bool)), SLOT(onFinished(bool)), Qt::DirectConnection);
-    connect(archiveInterface(), SIGNAL(userQuery(Query*)), SLOT(onUserQuery(Query*)));
+    connect(archiveInterface(), &ReadOnlyArchiveInterface::cancelled, this, &Job::onCancelled);
+    connect(archiveInterface(), &ReadOnlyArchiveInterface::error, this, &Job::onError);
+    connect(archiveInterface(), &ReadOnlyArchiveInterface::entry, this, &Job::onEntry);
+    connect(archiveInterface(), &ReadOnlyArchiveInterface::entryRemoved, this, &Job::onEntryRemoved);
+    connect(archiveInterface(), &ReadOnlyArchiveInterface::progress, this, &Job::onProgress);
+    connect(archiveInterface(), &ReadOnlyArchiveInterface::info, this, &Job::onInfo);
+    connect(archiveInterface(), &ReadOnlyArchiveInterface::finished, this, &Job::onFinished, Qt::DirectConnection);
+    connect(archiveInterface(), &ReadOnlyArchiveInterface::userQuery, this, &Job::onUserQuery);
 }
 
 void Job::onCancelled()
 {
-    qCDebug(KERFUFFLE) << "Cancelled emitted";
+    qCDebug(ARK) << "Cancelled emitted";
     setError(KJob::KilledJobError);
 }
 
@@ -135,7 +136,7 @@ void Job::onError(const QString & message, const QString & details)
 {
     Q_UNUSED(details)
 
-    qCDebug(KERFUFFLE) << "Error emitted:" << message;
+    qCDebug(ARK) << "Error emitted:" << message;
     setError(KJob::UserDefinedError);
     setErrorText(message);
 }
@@ -162,7 +163,7 @@ void Job::onEntryRemoved(const QString & path)
 
 void Job::onFinished(bool result)
 {
-    qCDebug(KERFUFFLE) << "Job finished, result:" << result << ", time:" << jobTimer.elapsed() << "ms";
+    qCDebug(ARK) << "Job finished, result:" << result << ", time:" << jobTimer.elapsed() << "ms";
 
     archiveInterface()->disconnect(this);
 
@@ -178,7 +179,7 @@ bool Job::doKill()
 {
     bool ret = archiveInterface()->doKill();
     if (!ret) {
-        qCWarning(KERFUFFLE) << "Killing does not seem to be supported here.";
+        qCWarning(ARK) << "Killing does not seem to be supported here.";
     }
     return ret;
 }
@@ -189,7 +190,7 @@ ListJob::ListJob(ReadOnlyArchiveInterface *interface, QObject *parent)
     , m_isPasswordProtected(false)
     , m_extractedFilesSize(0)
 {
-    qCDebug(KERFUFFLE) << "ListJob started";
+    qCDebug(ARK) << "ListJob started";
     connect(this, &ListJob::newEntry, this, &ListJob::onNewEntry);
 }
 
@@ -245,13 +246,13 @@ QString ListJob::subfolderName() const
     return m_subfolderName;
 }
 
-ExtractJob::ExtractJob(const QVariantList& files, const QString& destinationDir, ExtractionOptions options, ReadOnlyArchiveInterface *interface, QObject *parent)
+ExtractJob::ExtractJob(const QVariantList& files, const QString& destinationDir, const ExtractionOptions& options, ReadOnlyArchiveInterface *interface, QObject *parent)
     : Job(interface, parent)
     , m_files(files)
     , m_destinationDir(destinationDir)
     , m_options(options)
 {
-    qCDebug(KERFUFFLE) << "ExtractJob created";
+    qCDebug(ARK) << "ExtractJob created";
     setDefaultOptions();
 }
 
@@ -265,9 +266,16 @@ void ExtractJob::doWork()
     }
     emit description(this, desc);
 
+    QFileInfo destDirInfo(m_destinationDir);
+    if (destDirInfo.isDir() && (!destDirInfo.isWritable() || !destDirInfo.isExecutable())) {
+        onError(xi18n("Could not write to destination <filename>%1</filename>.<nl/>Check whether you have sufficient permissions.", m_destinationDir), QString());
+        onFinished(false);
+        return;
+    }
+
     connectToArchiveInterfaceSignals();
 
-    qCDebug(KERFUFFLE) << "Starting extraction with selected files:"
+    qCDebug(ARK) << "Starting extraction with selected files:"
              << m_files
              << "Destination dir:" << m_destinationDir
              << "Options:" << m_options;
@@ -283,7 +291,7 @@ void ExtractJob::setDefaultOptions()
 {
     ExtractionOptions defaultOptions;
 
-    defaultOptions[QLatin1String("PreservePaths")] = false;
+    defaultOptions[QStringLiteral("PreservePaths")] = false;
 
     ExtractionOptions::const_iterator it = defaultOptions.constBegin();
     for (; it != defaultOptions.constEnd(); ++it) {
@@ -308,12 +316,12 @@ AddJob::AddJob(const QStringList& files, const CompressionOptions& options , Rea
     , m_files(files)
     , m_options(options)
 {
-    qCDebug(KERFUFFLE) << "AddJob started";
+    qCDebug(ARK) << "AddJob started";
 }
 
 void AddJob::doWork()
 {
-    qCDebug(KERFUFFLE) << "AddJob doing work";
+    qCDebug(ARK) << "AddJob doing work";
 
     emit description(this, i18np("Adding a file", "Adding %1 files", m_files.count()));
 
@@ -346,7 +354,7 @@ void DeleteJob::doWork()
     Q_ASSERT(m_writeInterface);
 
     connectToArchiveInterfaceSignals();
-    int ret = m_writeInterface->deleteFiles(m_files);
+    bool ret = m_writeInterface->deleteFiles(m_files);
 
     if (!archiveInterface()->waitForFinishedSignal()) {
         onFinished(ret);
