@@ -30,6 +30,7 @@
 
 #include "kerfuffle_export.h"
 
+#include <QCheckBox>
 #include <QString>
 #include <QHash>
 #include <QWaitCondition>
@@ -74,6 +75,10 @@ private:
     QMutex m_responseMutex;
 };
 
+/* *****************************************************************
+ * Used to query the user if an existing file should be overwritten.
+ * *****************************************************************
+ */
 class KERFUFFLE_EXPORT OverwriteQuery : public Query
 {
 public:
@@ -96,6 +101,10 @@ private:
     bool m_multiMode;
 };
 
+/* **************************************
+ * Used to query the user for a password.
+ * **************************************
+ */
 class KERFUFFLE_EXPORT PasswordNeededQuery : public Query
 {
 public:
@@ -106,6 +115,31 @@ public:
     QString password();
 };
 
+/* *************************************************************
+ * Used to query the user if a corrupt archive should be loaded.
+ * *************************************************************
+ */
+class KERFUFFLE_EXPORT LoadCorruptQuery : public Query
+{
+public:
+    explicit LoadCorruptQuery(const QString& archiveFilename);
+    void execute() Q_DECL_OVERRIDE;
+
+    bool responseYes();
+};
+
+class KERFUFFLE_EXPORT ContinueExtractionQuery : public Query
+{
+public:
+    explicit ContinueExtractionQuery(const QString& error, const QString& archiveEntry);
+    void execute() Q_DECL_OVERRIDE;
+
+    bool responseCancelled();
+    bool dontAskAgain();
+private:
+    QCheckBox *m_chkDontAskAgain;
+};
+
 }
 
 #endif /* ifndef QUERIES_H */
