@@ -18,8 +18,9 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *
  */
-#include "app/logging.h"
+
 #include "infopanel.h"
+#include "ark_debug.h"
 #include "kerfuffle/archive_kerfuffle.h"
 
 #include <QLabel>
@@ -61,7 +62,7 @@ InfoPanel::~InfoPanel()
 
 void InfoPanel::updateWithDefaults()
 {
-    iconLabel->setPixmap(getDesktopIconForName(QLatin1String( "utilities-file-archiver" )));
+    iconLabel->setPixmap(getDesktopIconForName(QStringLiteral("utilities-file-archiver")));
 
     const QString currentFileName = prettyFileName();
 
@@ -103,7 +104,7 @@ void InfoPanel::setIndex(const QModelIndex& index)
         QMimeDatabase db;
         QMimeType mimeType;
         if (entry[ IsDirectory ].toBool()) {
-            mimeType = db.mimeTypeForName("inode/directory" );
+            mimeType = db.mimeTypeForName(QStringLiteral("inode/directory"));
         } else {
             mimeType = db.mimeTypeForFile(entry[ FileName ].toString(), QMimeDatabase::MatchExtension);
         }
@@ -141,7 +142,7 @@ void InfoPanel::setIndexes(const QModelIndexList &list)
     } else if (list.size() == 1) {
         setIndex(list[ 0 ]);
     } else {
-        iconLabel->setPixmap(getDesktopIconForName(QLatin1String( "utilities-file-archiver" )));
+        iconLabel->setPixmap(getDesktopIconForName(QStringLiteral("utilities-file-archiver")));
         fileName->setText(i18np("One file selected", "%1 files selected", list.size()));
         quint64 totalSize = 0;
         foreach(const QModelIndex& index, list) {
@@ -186,7 +187,7 @@ QString InfoPanel::metadataTextFor(const QModelIndex &index)
     QMimeType mimeType;
 
     if (entry[ IsDirectory ].toBool()) {
-        mimeType = db.mimeTypeForName("inode/directory" );
+        mimeType = db.mimeTypeForName(QStringLiteral("inode/directory"));
     } else {
         mimeType = db.mimeTypeForFile(entry[FileName].toString(), QMimeDatabase::MatchExtension);
     }
