@@ -19,8 +19,9 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *
  */
-#include "app/logging.h"
+
 #include "jobtracker.h"
+#include "ark_debug.h"
 
 #include <QDebug>
 
