@@ -225,6 +225,7 @@ void Part::extractSelectedFilesTo(const QString& localPath)
     Kerfuffle::ExtractionOptions options;
     options[QStringLiteral("PreservePaths")] = true;
     options[QStringLiteral("RemoveRootNode")] = true;
+    options[QStringLiteral("DragAndDrop")] = true;
 
     // Create and start the ExtractJob.
     ExtractJob *job = m_model->extractFiles(filesAndRootNodesForIndexes(addChildren(m_view->selectionModel()->selectedRows())), destination, options);
@@ -399,8 +400,8 @@ void Part::updateActions()
         menu->removeAction(menu->actions().last());
     }
 
-    const KConfigGroup conf(KSharedConfig::openConfig(), "DirSelect Dialog");
-    const QStringList dirHistory = conf.readPathEntry("History Items", QStringList());
+    const KConfigGroup conf(KSharedConfig::openConfig(), "ExtractDialog");
+    const QStringList dirHistory = conf.readPathEntry("DirHistory", QStringList());
 
     for (int i = 0; i < qMin(10, dirHistory.size()); ++i) {
         const QString dir = QUrl(dirHistory.value(i)).toString(QUrl::RemoveScheme | QUrl::NormalizePathSegments | QUrl::PreferLocalFile);
