@@ -96,7 +96,7 @@ ParameterList CliPlugin::parameterList() const
                                            << QStringLiteral("S")  //autoskip
                                            << QStringLiteral("Q"); //cancel
 
-        p[PasswordPromptPattern] = QStringLiteral("Enter password \\(will not be echoed\\) :");
+        p[PasswordPromptPattern] = QStringLiteral("Enter password \\(will not be echoed\\)");
         p[CorruptArchivePatterns] = QStringList() << QStringLiteral("Unexpected end of archive")
                                                   << QStringLiteral("Headers Error");
     }
