@@ -31,15 +31,15 @@ public:
     explicit CliPlugin(QObject *parent, const QVariantList &args);
     virtual ~CliPlugin();
 
-    virtual Kerfuffle::ParameterList parameterList() const;
-
-    virtual bool readListLine(const QString &line);
+    virtual void resetParsing() Q_DECL_OVERRIDE;
+    virtual Kerfuffle::ParameterList parameterList() const Q_DECL_OVERRIDE;
+    virtual bool readListLine(const QString &line) Q_DECL_OVERRIDE;
 
 private:
-    enum {
-        Header = 0,
-        Entry
-    } m_status;
+    enum ParseState {
+        ParseStateHeader = 0,
+        ParseStateEntry
+    } m_parseState;
 
     QString m_entryFilename;
     QString m_internalId;
