@@ -30,35 +30,41 @@ class CliPlugin : public Kerfuffle::CliInterface
     Q_OBJECT
 
 public:
-    explicit CliPlugin(QObject *parent, const QVariantList & args);
-
+    explicit CliPlugin(QObject *parent, const QVariantList &args);
     virtual ~CliPlugin();
 
-    virtual QString escapeFileName(const QString &fileName) const;
-
-    virtual Kerfuffle::ParameterList parameterList() const;
-
-    virtual bool readListLine(const QString &line);
+    virtual void resetParsing() Q_DECL_OVERRIDE;
+    virtual QString escapeFileName(const QString &fileName) const Q_DECL_OVERRIDE;
+    virtual Kerfuffle::ParameterList parameterList() const Q_DECL_OVERRIDE;
+    virtual bool readListLine(const QString &line) Q_DECL_OVERRIDE;
 
 private:
-    enum {
-        ParseStateColumnDescription1 = 0,
-        ParseStateColumnDescription2,
+
+    enum ParseState {
+        ParseStateTitle = 0,
+        ParseStateComment,
         ParseStateHeader,
         ParseStateEntryFileName,
         ParseStateEntryDetails,
-        ParseStateEntryIgnoredDetails
+        ParseStateLinkTarget
     } m_parseState;
 
-    QString m_entryFileName;
-    QHash<QString, QString> m_entryDetails;
+    void handleUnrar5Line(const QString &line);
+    void handleUnrar5Entry();
+    void handleUnrar4Line(const QString &line);
+    void handleUnrar4Entry();
+    void ignoreLines(int lines, ParseState nextState);
 
+    QStringList m_unrar4Details;
+    QHash<QString, QString> m_unrar5Details;
+
+    bool m_isUnrar5;
     bool m_isPasswordProtected;
+    bool m_isMultiVolume;
+    bool m_isSolid;
 
-    int m_remainingIgnoredSubHeaderLines;
-
-    bool m_isUnrarFree;
-    bool m_isUnrarVersion5;
+    int m_remainingIgnoreLines;
+    int m_linesComment;
 };
 
 #endif // CLIPLUGIN_H
