@@ -31,17 +31,19 @@ public:
     explicit CliPlugin(QObject *parent, const QVariantList &args);
     virtual ~CliPlugin();
 
+    virtual void resetParsing() Q_DECL_OVERRIDE;
     virtual QString escapeFileName(const QString &fileName) const Q_DECL_OVERRIDE;
-
     virtual Kerfuffle::ParameterList parameterList() const Q_DECL_OVERRIDE;
-
     virtual bool readListLine(const QString &line) Q_DECL_OVERRIDE;
 
 private:
-    enum {
-        Header = 0,
-        Entry
-    } m_status;
+    enum ParseState {
+        ParseStateHeader = 0,
+        ParseStateComment,
+        ParseStateEntry
+    } m_parseState;
+
+    int m_linesComment;
 };
 
 #endif // CLIPLUGIN_H
