@@ -25,8 +25,8 @@
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include "app/logging.h"
 #include "libarchivehandler.h"
+#include "ark_debug.h"
 #include "kerfuffle/kerfuffle_export.h"
 #include "kerfuffle/queries.h"
 
@@ -37,7 +37,6 @@
 #include <KPluginFactory>
 
 #include <QDateTime>
-#include <QDebug>
 #include <QDir>
 #include <QDirIterator>
 #include <QFile>
@@ -45,8 +44,6 @@
 #include <QStringList>
 #include <QSaveFile>
 
-Q_LOGGING_CATEGORY(KERFUFFLE_PLUGIN, "ark.kerfuffle.libarchive", QtWarningMsg)
-
 K_PLUGIN_FACTORY( LibArchivePluginFactory, registerPlugin< LibArchiveInterface >(); )
 
 struct LibArchiveInterface::ArchiveReadCustomDeleter
@@ -78,7 +75,7 @@ LibArchiveInterface::LibArchiveInterface(QObject *parent, const QVariantList & a
     , m_archiveReadDisk(archive_read_disk_new())
     , m_abortOperation(false)
 {
-    qCDebug(KERFUFFLE_PLUGIN) << "Loaded libarchive plugin";
+    qCDebug(ARK) << "Loaded libarchive plugin";
     archive_read_disk_set_standard_lookup(m_archiveReadDisk.data());
 }
 
@@ -88,7 +85,7 @@ LibArchiveInterface::~LibArchiveInterface()
 
 bool LibArchiveInterface::list()
 {
-    qCDebug(KERFUFFLE_PLUGIN) << "Listing archive contents";
+    qCDebug(ARK) << "Listing archive contents";
 
     ArchiveRead arch_reader(archive_read_new());
 
@@ -143,18 +140,18 @@ bool LibArchiveInterface::doKill()
     return true;
 }
 
-bool LibArchiveInterface::copyFiles(const QVariantList& files, const QString& destinationDirectory, ExtractionOptions options)
+bool LibArchiveInterface::copyFiles(const QVariantList& files, const QString& destinationDirectory, const ExtractionOptions& options)
 {
-    qCDebug(KERFUFFLE_PLUGIN) << "Changing current directory to " << destinationDirectory;
+    qCDebug(ARK) << "Changing current directory to " << destinationDirectory;
     QDir::setCurrent(destinationDirectory);
 
     const bool extractAll = files.isEmpty();
-    const bool preservePaths = options.value(QLatin1String( "PreservePaths" )).toBool();
-    bool removeRootNode = options.value(QLatin1String("RemoveRootNode"), QVariant()).toBool();
+    const bool preservePaths = options.value(QStringLiteral( "PreservePaths" )).toBool();
+    bool removeRootNode = options.value(QStringLiteral("RemoveRootNode"), QVariant()).toBool();
 
     // See if there is a singular RootNode.
-    QString rootNodeSingular = options.value(QLatin1String("RootNode"), QVariant()).toString();
-    if ((!rootNodeSingular.isEmpty()) && (!rootNodeSingular.endsWith(QLatin1Char('/')))) {
+    QString rootNodeSingular = options.value(QStringLiteral("RootNode"), QVariant()).toString();
+    if (!rootNodeSingular.isEmpty() && !rootNodeSingular.endsWith(QLatin1Char('/'))) {
         rootNodeSingular.append(QLatin1Char('/'));
     }
 
@@ -198,7 +195,7 @@ bool LibArchiveInterface::copyFiles(const QVariantList& files, const QString& de
             emit progress(0);
             //TODO: once information progress has been implemented, send
             //feedback here that the archive is being read
-            qCDebug(KERFUFFLE_PLUGIN) << "For getting progress information, the archive will be listed once";
+            qCDebug(ARK) << "For getting progress information, the archive will be listed once";
             m_emitNoEntries = true;
             list();
             m_emitNoEntries = false;
@@ -208,17 +205,20 @@ bool LibArchiveInterface::copyFiles(const QVariantList& files, const QString& de
         totalCount = files.size();
     }
 
-    qCDebug(KERFUFFLE_PLUGIN) << "Going to extract" << totalCount << "entries";
+    qCDebug(ARK) << "Going to extract" << totalCount << "entries";
 
-    m_currentExtractedFilesSize = 0;
 
+    // Initialize variables.
     bool overwriteAll = false; // Whether to overwrite all files
     bool skipAll = false; // Whether to skip all files
-    struct archive_entry *entry;
+    bool dontPromptErrors = false; // Whether to prompt for errors
+    m_currentExtractedFilesSize = 0;
+    int no_entries = 0;
 
+    struct archive_entry *entry;
     QString fileBeingRenamed;
 
-    int no_entries = 0;
+    // Iterate through all entries in archive.
     while (archive_read_next_header(arch.data(), &entry) == ARCHIVE_OK) {
 
         if (!extractAll && remainingFiles.isEmpty()) {
@@ -228,80 +228,83 @@ bool LibArchiveInterface::copyFiles(const QVariantList& files, const QString& de
         fileBeingRenamed.clear();
         int index;
 
-        // retry with renamed entry, fire an overwrite query again
-        // if the new entry also exists
+        // Retry with renamed entry, fire an overwrite query again
+        // if the new entry also exists.
     retry:
 
         const bool entryIsDir = S_ISDIR(archive_entry_mode(entry));
 
-        //we skip directories if not preserving paths
+        // Skip directories if not preserving paths.
         if (!preservePaths && entryIsDir) {
             archive_read_data_skip(arch.data());
             continue;
         }
 
-        //entryName is the name inside the archive, full path
+        // entryName is the name inside the archive, full path
         QString entryName = QDir::fromNativeSeparators(QFile::decodeName(archive_entry_pathname(entry)));
 
+        // For now we just can't handle absolute filenames in a tar archive.
+        // TODO: find out what to do here!!
         if (entryName.startsWith(QLatin1Char( '/' ))) {
-            //for now we just can't handle absolute filenames in a tar archive.
-            //TODO: find out what to do here!!
-            emit error(i18n("This archive contains archive entries with absolute paths, which are not yet supported by ark."));
-
+            emit error(i18n("This archive contains archive entries with absolute paths, "
+                            "which are not supported by Ark."));
             return false;
         }
 
-        if (remainingFiles.contains(QVariant::fromValue(fileRootNodePair(entryName))) || entryName == fileBeingRenamed || extractAll) {
+        // Should the entry be extracted?
+        if (extractAll ||
+            remainingFiles.contains(QVariant::fromValue(fileRootNodePair(entryName))) ||
+            entryName == fileBeingRenamed) {
 
             // Find the index of entry.
             if (entryName != fileBeingRenamed) {
                 index = files.indexOf(QVariant::fromValue(fileRootNodePair(entryName)));
             }
             if (!extractAll && index == -1) {
-                // If entry is not found in files, go to next entry.
+                // If entry is not found in files, skip entry.
                 continue;
             }
 
             // entryFI is the fileinfo pointing to where the file will be
-            // written from the archive
+            // written from the archive.
             QFileInfo entryFI(entryName);
-            //qCDebug(KERFUFFLE_PLUGIN) << "setting path to " << archive_entry_pathname( entry );
+            //qCDebug(ARK) << "setting path to " << archive_entry_pathname( entry );
 
             const QString fileWithoutPath(entryFI.fileName());
 
-            //If we DON'T preserve paths, we cut the path and set the entryFI
-            //fileinfo to the one without the path.
+            // If we DON'T preserve paths, we cut the path and set the entryFI
+            // fileinfo to the one without the path.
             if (!preservePaths) {
-                //empty filenames (ie dirs) should have been skipped already,
-                //so asserting
+                // Empty filenames (ie dirs) should have been skipped already,
+                // so asserting.
                 Q_ASSERT(!fileWithoutPath.isEmpty());
 
                 archive_entry_copy_pathname(entry, QFile::encodeName(fileWithoutPath).constData());
                 entryFI = QFileInfo(fileWithoutPath);
 
-            //OR, if the file has a rootNode attached, remove it from file path.
+            // OR, if the file has a rootNode attached, remove it from file path.
             } else if (!extractAll && removeRootNode && entryName != fileBeingRenamed &&
                        !files.at(index).value<fileRootNodePair>().rootNode.isEmpty()) {
 
-                //qCDebug(KERFUFFLE_PLUGIN) << "Removing" << files.at(index).value<fileRootNodePair>().rootNode << "from" << entryName;
+                //qCDebug(ARK) << "Removing" << files.at(index).value<fileRootNodePair>().rootNode << "from" << entryName;
 
                 const QString truncatedFilename(entryName.remove(0, files.at(index).value<fileRootNodePair>().rootNode.size()));
                 archive_entry_copy_pathname(entry, QFile::encodeName(truncatedFilename).constData());
                 entryFI = QFileInfo(truncatedFilename);
 
-            //OR, if a singular rootNode is provided, remove it from file path.
+            // OR, if a singular rootNode is provided, remove it from file path.
             } else if (removeRootNode &&
                        entryName != fileBeingRenamed &&
                        !rootNodeSingular.isEmpty()) {
 
-                //qCDebug(KERFUFFLE_PLUGIN) << "Removing" << rootNodeSingular << "from" << entryName;
+                //qCDebug(ARK) << "Removing" << rootNodeSingular << "from" << entryName;
 
                 const QString truncatedFilename(entryName.remove(0, rootNodeSingular.size()));
                 archive_entry_copy_pathname(entry, QFile::encodeName(truncatedFilename).constData());
                 entryFI = QFileInfo(truncatedFilename);
             }
 
-            //now check if the file about to be written already exists
+            // Check if the file about to be written already exists.
             if (!entryIsDir && entryFI.exists()) {
                 if (skipAll) {
                     archive_read_data_skip(arch.data());
@@ -336,34 +339,64 @@ bool LibArchiveInterface::copyFiles(const QVariantList& files, const QString& de
                 }
             }
 
-            //if there is an already existing directory:
+            // If there is an already existing directory.
             if (entryIsDir && entryFI.exists()) {
                 if (entryFI.isWritable()) {
-                    qCWarning(KERFUFFLE_PLUGIN) << "Warning, existing, but writable dir";
+                    qCWarning(ARK) << "Warning, existing, but writable dir";
                 } else {
-                    qCWarning(KERFUFFLE_PLUGIN) << "Warning, existing, but non-writable dir. skipping";
+                    qCWarning(ARK) << "Warning, existing, but non-writable dir. skipping";
                     archive_entry_clear(entry);
                     archive_read_data_skip(arch.data());
                     continue;
                 }
             }
 
-            int header_response;
-            //qCDebug(KERFUFFLE_PLUGIN) << "Writing " << fileWithoutPath << " to " << archive_entry_pathname(entry);
-            if ((header_response = archive_write_header(writer.data(), entry)) == ARCHIVE_OK) {
-                //if the whole archive is extracted and the total filesize is
-                //available, we use partial progress
-                copyData(arch.data(), writer.data(), (extractAll && m_extractedFilesSize));
-            } else if (header_response == ARCHIVE_WARN) {
-                qCWarning(KERFUFFLE_PLUGIN) << "Warning while writing " << entryName;
-            } else {
-                qCCritical(KERFUFFLE_PLUGIN) << "Writing header failed with error code " << header_response
-                << "While attempting to write " << entryName;
+            // Write the entry header and check return value.
+            const int returnCode = archive_write_header(writer.data(), entry);
+            switch (returnCode) {
+            case ARCHIVE_OK:
+                // If the whole archive is extracted and the total filesize is
+                // available, we use partial progress.
+                copyData(entryName, arch.data(), writer.data(), (extractAll && m_extractedFilesSize));
+                break;
+
+            case ARCHIVE_FAILED:
+                qCCritical(ARK) << "archive_write_header() has returned" << returnCode
+                                << "with errno" << archive_errno(writer.data());
+
+                // If they user previously decided to ignore future errors,
+                // don't bother prompting again.
+                if (!dontPromptErrors) {
+
+                    // Ask the user if he wants to continue extraction despite an error for this entry.
+                    Kerfuffle::ContinueExtractionQuery query(QLatin1String(archive_error_string(writer.data())),
+                                                             entryName);
+                    emit userQuery(&query);
+                    query.waitForResponse();
+
+                    if (query.responseCancelled()) {
+                        emit cancelled();
+                        return false;
+                    }
+                    dontPromptErrors = query.dontAskAgain();
+                }
+                break;
+
+            case ARCHIVE_FATAL:
+                qCCritical(ARK) << "archive_write_header() has returned" << returnCode
+                                << "with errno" << archive_errno(writer.data());
+                emit error(xi18nc("@info", "Extraction failed at:<nl/><filename>%1</filename>",
+                                  entryName));
+                return false;
+            default:
+                qCDebug(ARK) << "archive_write_header() returned" << returnCode
+                             << "which will be ignored.";
+                break;
             }
 
-            //if we only partially extract the archive and the number of
-            //archive entries is available we use a simple progress based on
-            //number of items extracted
+            // If we only partially extract the archive and the number of
+            // archive entries is available we use a simple progress based on
+            // number of items extracted.
             if (!extractAll && m_cachedArchiveEntryCount) {
                 ++entryNr;
                 emit progress(float(entryNr) / totalCount);
@@ -382,20 +415,20 @@ bool LibArchiveInterface::copyFiles(const QVariantList& files, const QString& de
 
     } // While entries left to read in archive.
 
-    qCDebug(KERFUFFLE_PLUGIN) << "Extracted" << no_entries << "entries";
+    qCDebug(ARK) << "Extracted" << no_entries << "entries";
 
     return archive_read_close(arch.data()) == ARCHIVE_OK;
 }
 
 bool LibArchiveInterface::addFiles(const QStringList& files, const CompressionOptions& options)
 {
-    qCDebug(KERFUFFLE_PLUGIN) << "Adding files" << files << "with CompressionOptions" << options;
+    qCDebug(ARK) << "Adding files" << files << "with CompressionOptions" << options;
 
     const bool creatingNewFile = !QFileInfo(filename()).exists();
-    const QString globalWorkDir = options.value(QLatin1String( "GlobalWorkDir" )).toString();
+    const QString globalWorkDir = options.value(QStringLiteral( "GlobalWorkDir" )).toString();
 
     if (!globalWorkDir.isEmpty()) {
-        qCDebug(KERFUFFLE_PLUGIN) << "GlobalWorkDir is set, changing dir to " << globalWorkDir;
+        qCDebug(ARK) << "GlobalWorkDir is set, changing dir to " << globalWorkDir;
         m_workDir.setPath(globalWorkDir);
         QDir::setCurrent(globalWorkDir);
     }
@@ -405,7 +438,7 @@ bool LibArchiveInterface::addFiles(const QStringList& files, const CompressionOp
     ArchiveRead arch_reader;
     if (!creatingNewFile) {
         arch_reader.reset(archive_read_new());
-        if (!(arch_reader.data())) {
+        if (!arch_reader.data()) {
             emit error(i18n("The archive reader could not be initialized."));
             return false;
         }
@@ -440,35 +473,34 @@ bool LibArchiveInterface::addFiles(const QStringList& files, const CompressionOp
         return false;
     }
 
-    //pax_restricted is the libarchive default, let's go with that.
+    // pax_restricted is the libarchive default, let's go with that.
     archive_write_set_format_pax_restricted(arch_writer.data());
 
     int ret;
     if (creatingNewFile) {
-        if (filename().right(2).toUpper() == QLatin1String( "GZ" )) {
-            qCDebug(KERFUFFLE_PLUGIN) << "Detected gzip compression for new file";
+        if (filename().right(2).toUpper() == QLatin1String("GZ")) {
+            qCDebug(ARK) << "Detected gzip compression for new file";
             ret = archive_write_add_filter_gzip(arch_writer.data());
-        } else if (filename().right(3).toUpper() == QLatin1String( "BZ2" )) {
-            qCDebug(KERFUFFLE_PLUGIN) << "Detected bzip2 compression for new file";
+        } else if (filename().right(3).toUpper() == QLatin1String("BZ2")) {
+            qCDebug(ARK) << "Detected bzip2 compression for new file";
             ret = archive_write_add_filter_bzip2(arch_writer.data());
-        } else if (filename().right(2).toUpper() == QLatin1String( "XZ" )) {
-            qCDebug(KERFUFFLE_PLUGIN) << "Detected xz compression for new file";
+        } else if (filename().right(2).toUpper() == QLatin1String("XZ")) {
+            qCDebug(ARK) << "Detected xz compression for new file";
             ret = archive_write_add_filter_xz(arch_writer.data());
-        } else if (filename().right(4).toUpper() == QLatin1String( "LZMA" )) {
-            qCDebug(KERFUFFLE_PLUGIN) << "Detected lzma compression for new file";
+        } else if (filename().right(4).toUpper() == QLatin1String("LZMA")) {
+            qCDebug(ARK) << "Detected lzma compression for new file";
             ret = archive_write_add_filter_lzma(arch_writer.data());
-        } else if (filename().right(3).toUpper() == QLatin1String( "TAR" )) {
-            qCDebug(KERFUFFLE_PLUGIN) << "Detected no compression for new file (pure tar)";
+        } else if (filename().right(3).toUpper() == QLatin1String("TAR")) {
+            qCDebug(ARK) << "Detected no compression for new file (pure tar)";
             ret = archive_write_add_filter_none(arch_writer.data());
         } else {
-            qCDebug(KERFUFFLE_PLUGIN) << "Falling back to gzip";
+            qCDebug(ARK) << "Falling back to gzip";
             ret = archive_write_add_filter_gzip(arch_writer.data());
         }
 
         if (ret != ARCHIVE_OK) {
-            emit error(xi18nc("@info", "Setting the compression method failed with the following error: <message>%1</message>",
-                       QLatin1String(archive_error_string(arch_writer.data()))));
-
+            emit error(xi18nc("@info", "Setting the compression method failed with the following error:<nl/><message>%1</message>",
+                              QLatin1String(archive_error_string(arch_writer.data()))));
             return false;
         }
     } else {
@@ -489,32 +521,32 @@ bool LibArchiveInterface::addFiles(const QStringList& files, const CompressionOp
             ret = archive_write_add_filter_none(arch_writer.data());
             break;
         default:
-            emit error(i18n("The compression type '%1' is not supported by Ark.", QLatin1String(archive_filter_name(arch_reader.data(), 0))));
+            emit error(i18n("The compression type '%1' is not supported by Ark.",
+                            QLatin1String(archive_filter_name(arch_reader.data(), 0))));
             return false;
         }
 
         if (ret != ARCHIVE_OK) {
-            emit error(xi18nc("@info", "Setting the compression method failed with the following error: <message>%1</message>", QLatin1String(archive_error_string(arch_writer.data()))));
+            emit error(xi18nc("@info", "Setting the compression method failed with the following error:<nl/><message>%1</message>",
+                              QLatin1String(archive_error_string(arch_writer.data()))));
             return false;
         }
     }
 
     ret = archive_write_open_fd(arch_writer.data(), tempFile.handle());
     if (ret != ARCHIVE_OK) {
-        emit error(xi18nc("@info", "Opening the archive for writing failed with the following error: <message>%1</message>", QLatin1String(archive_error_string(arch_writer.data()))));
+        emit error(xi18nc("@info", "Opening the archive for writing failed with the following error:<nl/><message>%1</message>",
+                          QLatin1String(archive_error_string(arch_writer.data()))));
         return false;
     }
 
-    //**************** first write the new files
+    // First write the new files.
     foreach(const QString& selectedFile, files) {
-        bool success;
-
-        success = writeFile(selectedFile, arch_writer.data());
-
-        if (!success) {
+        if (!writeFile(selectedFile, arch_writer.data())) {
             return false;
         }
 
+        // For directories, write all subfiles/folders.
         if (QFileInfo(selectedFile).isDir()) {
             QDirIterator it(selectedFile,
                             QDir::AllEntries | QDir::Readable |
@@ -522,7 +554,7 @@ bool LibArchiveInterface::addFiles(const QStringList& files, const CompressionOp
                             QDirIterator::Subdirectories);
 
             while (it.hasNext()) {
-                const QString path = it.next();
+                QString path = it.next();
 
                 if ((it.fileName() == QLatin1String("..")) ||
                     (it.fileName() == QLatin1String("."))) {
@@ -531,11 +563,11 @@ bool LibArchiveInterface::addFiles(const QStringList& files, const CompressionOp
 
                 const bool isRealDir = it.fileInfo().isDir() && !it.fileInfo().isSymLink();
 
-                success = writeFile(path +
-                                    (isRealDir ? QLatin1String( "/" ) : QLatin1String( "" )),
-                                    arch_writer.data());
+                if (isRealDir) {
+                    path.append(QLatin1Char('/'));
+                }
 
-                if (!success) {
+                if (!writeFile(path, arch_writer.data())) {
                     return false;
                 }
             }
@@ -544,26 +576,41 @@ bool LibArchiveInterface::addFiles(const QStringList& files, const CompressionOp
 
     struct archive_entry *entry;
 
-    //and if we have old elements...
+    // If we have old archive entries.
     if (!creatingNewFile) {
-        //********** copy old elements from previous archive to new archive
+
+        // Copy old entries from previous archive to new archive.
         while (archive_read_next_header(arch_reader.data(), &entry) == ARCHIVE_OK) {
-            if (m_writtenFiles.contains(QFile::decodeName(archive_entry_pathname(entry)))) {
+
+            const QString entryName = QFile::decodeName(archive_entry_pathname(entry));
+
+            if (m_writtenFiles.contains(entryName)) {
                 archive_read_data_skip(arch_reader.data());
-                qCDebug(KERFUFFLE_PLUGIN) << "Entry already existing, will be refresh: ===> " << archive_entry_pathname(entry);
+                qCDebug(ARK) << entryName << "is already present in the new archive, skipping.";
                 continue;
             }
 
-            int header_response;
-            if ((header_response = archive_write_header(arch_writer.data(), entry)) == ARCHIVE_OK) {
-                //if the whole archive is extracted and the total filesize is
-                //available, we use partial progress
-                copyData(arch_reader.data(), arch_writer.data(), false);
-            } else {
-                qCCritical(KERFUFFLE_PLUGIN) << "Writing header failed with error code " << header_response;
-                return false;
-            }
+            const int returnCode = archive_write_header(arch_writer.data(), entry);
 
+            switch (returnCode) {
+            case ARCHIVE_OK:
+                // If the whole archive is extracted and the total filesize is
+                // available, we use partial progress.
+                copyData(QLatin1String(archive_entry_pathname(entry)), arch_reader.data(), arch_writer.data(), false);
+                break;
+            case ARCHIVE_FAILED:
+            case ARCHIVE_FATAL:
+                qCCritical(ARK) << "archive_write_header() has returned" << returnCode
+                                << "with errno" << archive_errno(arch_writer.data());
+                emit error(xi18nc("@info", "Compression failed while processing:<nl/>"
+                                  "<filename>%1</filename><nl/><nl/>Operation aborted.", entryName));
+                QFile::remove(tempFile.fileName());
+                return false;
+            default:
+                qCWarning(ARK) << "archive_writer_header() has returned" << returnCode
+                               << "which will be ignored.";
+                break;
+            }
             archive_entry_clear(entry);
         }
     }
@@ -581,7 +628,7 @@ bool LibArchiveInterface::addFiles(const QStringList& files, const CompressionOp
 
 bool LibArchiveInterface::deleteFiles(const QVariantList& files)
 {
-    qCDebug(KERFUFFLE_PLUGIN) << "Deleting files" << files;
+    qCDebug(ARK) << "Deleting files" << files;
 
     ArchiveRead arch_reader(archive_read_new());
     if (!(arch_reader.data())) {
@@ -608,7 +655,7 @@ bool LibArchiveInterface::deleteFiles(const QVariantList& files)
     // before close()'ing the file descriptor).
     QSaveFile tempFile(filename());
     if (!tempFile.open(QIODevice::WriteOnly | QIODevice::Unbuffered)) {
-        emit error(xi18nc("@info", "Failed to create a temporary file to compress <filename>%1</filename>.", filename()));
+        emit error(i18nc("@info", "Failed to create a temporary file."));
         return false;
     }
 
@@ -618,7 +665,7 @@ bool LibArchiveInterface::deleteFiles(const QVariantList& files)
         return false;
     }
 
-    //pax_restricted is the libarchive default, let's go with that.
+    // pax_restricted is the libarchive default, let's go with that.
     archive_write_set_format_pax_restricted(arch_writer.data());
 
     int ret;
@@ -644,36 +691,51 @@ bool LibArchiveInterface::deleteFiles(const QVariantList& files)
     }
 
     if (ret != ARCHIVE_OK) {
-        emit error(xi18nc("@info", "Setting the compression method failed with the following error: <message>%1</message>", QLatin1String(archive_error_string(arch_writer.data()))));
+        emit error(xi18nc("@info", "Setting the compression method failed with the following error:"
+                          "<nl/><message>%1</message>", QLatin1String(archive_error_string(arch_writer.data()))));
         return false;
     }
 
     ret = archive_write_open_fd(arch_writer.data(), tempFile.handle());
     if (ret != ARCHIVE_OK) {
-        emit error(xi18nc("@info", "Opening the archive for writing failed with the following error: <message>%1</message>", QLatin1String(archive_error_string(arch_writer.data()))));
+        emit error(xi18nc("@info", "Opening the archive for writing failed with the following error:"
+                          "<nl/><message>%1</message>", QLatin1String(archive_error_string(arch_writer.data()))));
         return false;
     }
 
     struct archive_entry *entry;
 
-    //********** copy old elements from previous archive to new archive
+    // Copy old elements from previous archive to new archive.
     while (archive_read_next_header(arch_reader.data(), &entry) == ARCHIVE_OK) {
-        if (files.contains(QFile::decodeName(archive_entry_pathname(entry)))) {
+
+        const QString entryName = QFile::decodeName(archive_entry_pathname(entry));
+
+        if (files.contains(entryName)) {
             archive_read_data_skip(arch_reader.data());
-            qCDebug(KERFUFFLE_PLUGIN) << "Entry to be deleted, skipping"
-                     << archive_entry_pathname(entry);
-            emit entryRemoved(QFile::decodeName(archive_entry_pathname(entry)));
+            qCDebug(ARK) << "Entry to be deleted, skipping" << entryName;
+            emit entryRemoved(entryName);
             continue;
         }
 
-        int header_response;
-        if ((header_response = archive_write_header(arch_writer.data(), entry)) == ARCHIVE_OK) {
-            //if the whole archive is extracted and the total filesize is
-            //available, we use partial progress
-            copyData(arch_reader.data(), arch_writer.data(), false);
-        } else {
-            qCCritical(KERFUFFLE_PLUGIN) << "Writing header failed with error code " << header_response;
+        const int returnCode = archive_write_header(arch_writer.data(), entry);
+
+        switch (returnCode) {
+        case ARCHIVE_OK:
+            // If the whole archive is extracted and the total filesize is
+            // available, we use partial progress.
+            copyData(QLatin1String(archive_entry_pathname(entry)), arch_reader.data(), arch_writer.data(), false);
+            break;
+        case ARCHIVE_FAILED:
+        case ARCHIVE_FATAL:
+            qCCritical(ARK) << "archive_write_header() has returned" << returnCode
+                            << "with errno" << archive_errno(arch_writer.data());
+            emit error(xi18nc("@info", "Compression failed while processing:<nl/>"
+                              "<filename>%1</filename><nl/><nl/>Operation aborted.", entryName));
             return false;
+        default:
+            qCDebug(ARK) << "archive_writer_header() has returned" << returnCode
+                         << "which will be ignored.";
+            break;
         }
     }
 
@@ -752,10 +814,10 @@ void LibArchiveInterface::copyData(const QString& filename, struct archive *dest
 
     readBytes = file.read(buff, sizeof(buff));
     while (readBytes > 0) {
-        /* int writeBytes = */
         archive_write_data(dest, buff, readBytes);
         if (archive_errno(dest) != ARCHIVE_OK) {
-            qCCritical(KERFUFFLE_PLUGIN) << "Error while writing..." << archive_error_string(dest) << "(error nb =" << archive_errno(dest) << ')';
+            qCCritical(ARK) << "Error while writing" << filename << ":" << archive_error_string(dest)
+                            << "(error no =" << archive_errno(dest) << ')';
             return;
         }
 
@@ -770,17 +832,17 @@ void LibArchiveInterface::copyData(const QString& filename, struct archive *dest
     file.close();
 }
 
-void LibArchiveInterface::copyData(struct archive *source, struct archive *dest, bool partialprogress)
+void LibArchiveInterface::copyData(const QString& filename, struct archive *source, struct archive *dest, bool partialprogress)
 {
     char buff[10240];
     ssize_t readBytes;
 
     readBytes = archive_read_data(source, buff, sizeof(buff));
     while (readBytes > 0) {
-        /* int writeBytes = */
         archive_write_data(dest, buff, readBytes);
         if (archive_errno(dest) != ARCHIVE_OK) {
-            qCCritical(KERFUFFLE_PLUGIN) << "Error while extracting..." << archive_error_string(dest) << "(error nb =" << archive_errno(dest) << ')';
+            qCCritical(ARK) << "Error while extracting" << filename << ":" << archive_error_string(dest)
+                            << "(error no =" << archive_errno(dest) << ')';
             return;
         }
 
@@ -805,7 +867,7 @@ bool LibArchiveInterface::writeFile(const QString& fileName, struct archive* arc
     //          so that symlinks aren't resolved automatically
     // TODO: this kind of call should be moved upwards in the
     //       class hierarchy to avoid code duplication
-    const QString relativeName = m_workDir.relativeFilePath(fileName) + (trailingSlash ? QLatin1String( "/" ) : QLatin1String( "" ));
+    const QString relativeName = m_workDir.relativeFilePath(fileName) + (trailingSlash ? QStringLiteral( "/" ) : QStringLiteral( "" ));
 
     // #253059: Even if we use archive_read_disk_entry_from_file,
     //          libarchive may have been compiled without HAVE_LSTAT,
@@ -820,14 +882,14 @@ bool LibArchiveInterface::writeFile(const QString& fileName, struct archive* arc
     archive_entry_copy_sourcepath(entry, QFile::encodeName(fileName).constData());
     archive_read_disk_entry_from_file(m_archiveReadDisk.data(), entry, -1, &st);
 
-    qCDebug(KERFUFFLE_PLUGIN) << "Writing new entry " << archive_entry_pathname(entry);
+    qCDebug(ARK) << "Writing new entry " << archive_entry_pathname(entry);
     if ((header_response = archive_write_header(arch_writer, entry)) == ARCHIVE_OK) {
-        //if the whole archive is extracted and the total filesize is
-        //available, we use partial progress
+        // If the whole archive is extracted and the total filesize is
+        // available, we use partial progress.
         copyData(fileName, arch_writer, false);
     } else {
-        qCCritical(KERFUFFLE_PLUGIN) << "Writing header failed with error code " << header_response;
-        qCCritical(KERFUFFLE_PLUGIN) << "Error while writing..." << archive_error_string(arch_writer) << "(error nb =" << archive_errno(arch_writer) << ')';
+        qCCritical(ARK) << "Writing header failed with error code " << header_response;
+        qCCritical(ARK) << "Error while writing..." << archive_error_string(arch_writer) << "(error no =" << archive_errno(arch_writer) << ')';
 
         emit error(xi18nc("@info Error in a message box",
                           "Ark could not compress <filename>%1</filename>:<nl/>%2",
