@@ -37,7 +37,7 @@ public:
     virtual ~LibSingleFileInterface();
 
     virtual bool list() Q_DECL_OVERRIDE;
-    virtual bool copyFiles(const QList<QVariant> & files, const QString & destinationDirectory, Kerfuffle::ExtractionOptions options) Q_DECL_OVERRIDE;
+    virtual bool copyFiles(const QList<QVariant>& files, const QString& destinationDirectory, const Kerfuffle::ExtractionOptions& options) Q_DECL_OVERRIDE;
 
 protected:
     const QString uncompressedFileName() const;
